==> qs-component-0.1.3.tgz: package/es6/decorate.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';

export default function (component) {
    return function (_component) {
        _inherits(_class, _component);

        function _class() {
            _classCallCheck(this, _class);

            return _possibleConstructorReturn(this, Object.getPrototypeOf(_class).apply(this, arguments));
        }

        _createClass(_class, [{
            key: 'getQuery',

            /*
             * This needs to be overloaded to return an object
             * representing the current query string, e.g.
             * /page?foo=bar&page=1 should return
             * {foo: bar, page: 1}
             */
            value: function getQuery() {
                throw new Error('This needs to be overloaded');
            }

            /*
             * This needs to be overloaded to take a query object
             * and replace the current query string with it.
             *
             * In this context, replace means replace the last entry
             * in history, not add a new one.
             *
             * This is used for deleting default query parameters from the
             * query string, so if a user is linked to /foo?page=1 they are
             * replaced to /foo.  The user should not be able to get back
             * to the page=1 query string with their back button.
             */

        }, {
            key: 'replaceQuery',
            value: function replaceQuery() {
                // eslint-disable-line react/sort-comp
                throw new Error('This needs to be overloaded');
            }

            /*
             * This needs to be overloaded to take a query object
             * and push it onto the history stack.
             */

        }, {
            key: 'pushQuery',
            value: function pushQuery() {
                throw new Error('This needs to be overloaded');
            }

            /*
             * Child classes need to implement this to provide the default
             * state values for variables from the query string.  This
             * values will always be available, whether the query string is
             * specified or not.
             *
             * These values get maintained in this.state.qstate
             */

        }, {
            key: 'getDefaultQuery',
            value: function getDefaultQuery() {
                throw new Error('This needs to be overloaded');
            }
        }, {
            key: 'componentWillMount',
            value: function componentWillMount() {
                var _this2 = this;

                var defaults = this.getDefaultQuery();
                var query = this.getQuery();

                this.setState({ qstate: Object.assign({}, defaults, query) }, function () {
                    if (Object.keys(query).filter(function (k) {
                        return defaults[k] === query[k];
                    }).length > 0) {
                        _this2.replaceQuery(_this2._cleanupQueryString(_this2.state.qstate));
                    }
                });

                if (_get(Object.getPrototypeOf(_class.prototype), 'hasOwnProperty', this).call(this, 'componentWillMount')) {
                    _get(Object.getPrototypeOf(_class.prototype), 'componentWillMount', this).call(this);
                }
            }
        }, {
            key: 'setQState',
            value: function setQState(newState, callback) {
                var _this3 = this;

                var qstate = this._extractQState(newState);

                var _callback = function _callback() {
                    _this3.pushQuery(_this3._cleanupQueryString(qstate));

                    if (typeof callback === 'function') {
                        callback.call(_this3);
                    }
                };

                this.setState({ qstate: qstate }, _callback);
            }
        }, {
            key: '_extractQState',
            value: function _extractQState(newState) {
                var qstate = {};

                if (typeof newState === 'function') {
                    var prevState = Object.assign({}, this.state.qstate);
                    Object.assign(qstate, this.getDefaultQuery(), this.state.qstate, newState.call(this, prevState, this.props));
                } else {
                    Object.assign(qstate, this.getDefaultQuery(), this.state.qstate, newState);
                }
            }
        }, {
            key: '_cleanupQueryString',
            value: function _cleanupQueryString(query) {
                var defaults = this.getDefaultQuery();
                Object.keys(query).filter(function (key) {
                    return query[key] === defaults[key];
                }).forEach(function (key) {
                    return delete query[key];
                });
                return query;
            }
        }]);

        return _class;
    }(component);
}

==> qs-component-0.2.1.tgz: package/es6/decorate.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';

export default function (component) {
    return function (_component) {
        _inherits(_class, _component);

        function _class() {
            _classCallCheck(this, _class);

            return _possibleConstructorReturn(this, Object.getPrototypeOf(_class).apply(this, arguments));
        }

        _createClass(_class, [{
            key: 'getQuery',

            /*
             * This needs to be overloaded to return an object
             * representing the current query string, e.g.
             * /page?foo=bar&page=1 should return
             * {foo: bar, page: 1}
             */
            value: function getQuery() {
                throw new Error('This needs to be overloaded');
            }

            /*
             * This needs to be overloaded to take a query object
             * and replace the current query string with it.
             *
             * In this context, replace means replace the last entry
             * in history, not add a new one.
             *
             * This is used for deleting default query parameters from the
             * query string, so if a user is linked to /foo?page=1 they are
             * replaced to /foo.  The user should not be able to get back
             * to the page=1 query string with their back button.
             */

        }, {
            key: 'replaceQuery',
            value: function replaceQuery() {
                // eslint-disable-line react/sort-comp
                throw new Error('This needs to be overloaded');
            }

            /*
             * This needs to be overloaded to take a query object
             * and push it onto the history stack.
             */

        }, {
            key: 'pushQuery',
            value: function pushQuery() {
                throw new Error('This needs to be overloaded');
            }

            /*
             * Child classes need to implement this to provide the default
             * state values for variables from the query string.  This
             * values will always be available, whether the query string is
             * specified or not.
             *
             * These values get maintained in this.state.qstate
             */

        }, {
            key: 'getDefaultQuery',
            value: function getDefaultQuery() {
                throw new Error('This needs to be overloaded');
            }
        }, {
            key: 'componentWillMount',
            value: function componentWillMount() {
                var _this2 = this;

                var defaults = this.getDefaultQuery();
                var query = this.getQuery();

                this.setState({ qstate: _extends({}, defaults, query) }, function () {
                    if (Object.keys(query).filter(function (k) {
                        return defaults[k] === query[k];
                    }).length > 0) {
                        _this2.replaceQuery(_this2._cleanupQueryString(_this2.state.qstate));
                    }
                });

                if (typeof _get(Object.getPrototypeOf(_class.prototype), 'componentWillMount', this) === 'function') {
                    _get(Object.getPrototypeOf(_class.prototype), 'componentWillMount', this).call(this);
                }
            }
        }, {
            key: 'setQState',
            value: function setQState(newState, callback) {
                var _this3 = this;

                var qstate = this._extractQState(newState);

                var _callback = function _callback() {
                    _this3.pushQuery(_this3._cleanupQueryString(qstate));

                    if (typeof callback === 'function') {
                        callback.call(_this3);
                    }
                };

                this.setState({ qstate: qstate }, _callback);
            }
        }, {
            key: '_extractQState',
            value: function _extractQState(newState) {
                // 😎
                return _extends({}, this.getDefaultQuery(), this.state.qstate, typeof newState === 'function' ? newState.call(this, this.state.qstate, this.props) : newState);
            }
        }, {
            key: '_cleanupQueryString',
            value: function _cleanupQueryString(query) {
                var defaults = this.getDefaultQuery();
                Object.keys(query).filter(function (key) {
                    return query[key] === defaults[key];
                }).forEach(function (key) {
                    return delete query[key];
                });
                return query;
            }
        }]);

        return _class;
    }(component);
}
